import { createRouter, createWebHashHistory } from 'vue-router'

const routes = [
    {
        path: '/doctor',
        name: 'Home',
        redirect: '/doctor/followUp/list'
    },
    {
        path: '/resident',
        name: 'resident',
        component: () => import(/* webpackChunkName: "resident" */ '@/resident/Resident.vue'),
        children: [
            {
                path: 'screening/first/agree',
                name: 'resident-screening-first-agree',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/agree/Agree.vue')
            },
            {
                path: 'screening/first/form',
                name: 'resident-screening-first-form',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/form/Index.vue')
            },
            {
                path: 'screening/first/detail',
                name: 'resident-screening-first-detail',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/detail/List.vue')
            },
            {
                path: 'screening/first/detail/:id',
                name: 'resident-screening-first-detail-id',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/detail/Detail.vue')
            }


        ]
    },
    {
        path: '/doctor',
        name: 'doctor',
        component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/Doctor'),
        children: [
            {
                path: 'followUp/list',
                name: 'followUp-list',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/List')
            },
            {
                path: 'followUp/search',
                name: 'followUp-search',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/search/Search.vue')
            },
            {
                path: 'followUp/generalFU/detail',
                name: 'followUp-generalFU-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/generalFU/detail/Detail')
            },
            {
                path: 'followUp/generalFU/add',
                name: 'followUp-generalFU-add',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/generalFU/form/Index')
            },
            {
                path: 'resident',
                name: 'doctor-resident',
                redirect: '/doctor/resident/base',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/resident/Index.vue'),
                children: [
                    // 基本信息
                    {
                        path: 'base',
                        name: 'doctor-resident-base',
                        component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/resident/Base.vue')
                    },
                    // 随访记录
                    {
                        path: 'visit',
                        name: 'doctor-resident-visit',
                        component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/resident/Visit.vue')
                    }
                ]
            },
            //修改基本信息
            {
                path: 'resident/base/update',
                name: 'doctor-resident-base-update',
                component: () => import(/* webpackChunkName: "page-doctor" */ '@/doctor/resident/form/BaseInfo.vue')
            }
        ]
    },
    {
        path: '/residentWX',
        name: 'residentWX',
        component: () => import(/* webpackChunkName: "residentWX" */ '@/residentWX/ResidentWX.vue'),
        children: [
            {
                path: 'screening/list',
                name: 'residentWX-screening-list',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/List.vue')
            },
            {
                path: 'screening/firstDetail/:id',
                name: 'resident-screening-firstDetail',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/detail/FirstDetail.vue')
            },
            {
                path: 'screening/secondDetail/:id',
                name: 'resident-screening-secondDetail',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/detail/SecondDetail.vue')
            },
            {
                path: 'visit/list',
                name: 'residentWX-visit-List',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/List.vue')
            },
            //通用随访详情
            {
                path: 'visit/GeneralFUDetail/:relationId',
                name: 'resident-visit-GeneralFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/GeneralFUDetail.vue')
            },
            //主要慢病高危详情
            {
                path: 'visit/FirstFUDetail/:id',
                name: 'resident-visit-FirstFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/FirstFUDetail.vue')
            },
            //专病高危详情
            {
                path: 'visit/SecondFUDetail/:id',
                name: 'resident-visit-SecondFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/SecondFUDetail.vue')
            },
            // 专病随访详情
            {
                path: 'visit/SeparateFUDetail/:relationId/:diseaseType',
                name: 'resident-visit-SeparateFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/SeparateFUDetail.vue')
            },
            // 健康指导宣教
            {
                path: 'guide/list',
                name: 'residentWX-guide-list',
                component: () => import(/* webpackChunkName: "residentWX-guide" */ '@/residentWX/guide/List.vue')
            },
            {
                path: 'guide/list/:id',
                name: 'residentWX-guide-Detail',
                component: () => import(/* webpackChunkName: "residentWX-guide" */ '@/residentWX/guide/Detail.vue')
            },
            {
                path: 'nim',
                name: 'residentWX-nim',
                component: () => import(/* webpackChunkName: "residentWX-nim" */ '@/residentWX/nim/Index.vue'),
            },
            {
                path: 'nim/:id',
                name: 'residentWX-nim-session',
                component: () => import(/* webpackChunkName: "residentWX-nim" */ '@/residentWX/nim/Session.vue'),
            }
        ]
    },
    {
        path: '/test',
        name: 'Test',
        component: () => import(/* webpackChunkName: "test" */ '@/test/Index.vue'),
    }
]

const router = createRouter({
    history: createWebHashHistory(),
    routes
})

export default router
